pub struct Input {
pub identifier_: Option<FHIRCanonical>,
pub profile: Option<FHIRString>,
pub url: Option<FHIRCanonical>,
pub supportedOnly: Option<FHIRBoolean>,
}Fields
identifier_: Option<FHIRCanonical>A logical identifier (i.e. ‘StructureDefinition.identifier’’). The server must know the StructureDefinition or be able to retrieve it from other known repositories.
profile: Option<FHIRString>The StructureDefinition is provided directly as part of the request. Servers may choose not to accept profiles in this fashion
url: Option<FHIRCanonical>The StructureDefinition’s official URL (i.e. ‘StructureDefinition.url’). The server must know the StructureDefinition or be able to retrieve it from other known repositories.
supportedOnly: Option<FHIRBoolean>If true, the questionnaire will only include those elements marked as “mustSupport=‘true’” in the StructureDefinition.